@@ -11,18 +11,18 @@ check_can_create_screenlog_file <- function( # nolint indeed a long function nam
   beast2_options
 ) {
   # Extract the screenlog file
-  testthat::expect_true(file.exists(beast2_options$input_filename))
+  check_true(file.exists(beast2_options$input_filename))
   text <- readr::read_lines(beast2_options$input_filename, progress = FALSE)
   screenlog_line <- stringr::str_subset(
     string = text,
     pattern = "<logger id=\"screenlog\""
   )
-  testthat::expect_equal(length(screenlog_line), 1)
+  check_true(length(screenlog_line) == 1)
   matches <- stringr::str_match(
     string = screenlog_line,
     pattern = "fileName=\\\"([:graph:]+)\\\" "
   )
-  testthat::expect_equal(ncol(matches), 2)
+  check_true(ncol(matches) == 2)
   screenlog_filename <- matches[1, 2]
 
   if (is.na(screenlog_filename)) return()
@@ -32,7 +32,7 @@ check_can_create_screenlog_file <- function( # nolint indeed a long function nam
   }
 
   tryCatch(
-    beastier::check_can_create_file(
+    check_can_create_file(
       filename = screenlog_filename, overwrite = FALSE
     ),
     error = function(e) {
