@@ -14,7 +14,7 @@
 create_beast2_input_file_folder <- function( # nolint indeed a long function name
   beast2_options
 ) {
-  beastier::check_beast2_options(beast2_options)
+  check_beast2_options(beast2_options)
   dir.create(
     dirname(beast2_options$input_filename),
     showWarnings = FALSE,
