@@ -11,14 +11,14 @@
 #' @author Richèl J.C. Bilderbeek
 #' @export
 create_beast2_version_cmd <- function(
-  beast2_path = beastier::get_default_beast2_path()
+  beast2_path = get_default_beast2_path()
 ) {
-  if (beastier::is_jar_path(beast2_path)) {
+  if (is_jar_path(beast2_path)) {
     create_beast2_version_cmd_jar(
       beast2_jar_path = beast2_path
     )
   } else {
-    testit::assert(beastier::is_bin_path(beast2_path))
+    check_true(is_bin_path(beast2_path))
     create_beast2_version_cmd_bin(
       beast2_bin_path = beast2_path
     )
@@ -42,12 +42,12 @@ create_beast2_version_cmd_jar <- function(
   beast2_jar_path = get_default_beast2_jar_path()
 ) {
   beautier::check_file_exists(beast2_jar_path, "beast2_jar_path")
-  testit::assert(beastier::is_jar_path(beast2_jar_path))
+  check_true(is_jar_path(beast2_jar_path))
   cmds <- c(
-    beastier::get_default_java_path(),
+    get_default_java_path(),
     "-cp",
     paste0("\"", beast2_jar_path, "\""),
-    beastier::get_beast2_main_class_name(),
+    get_beast2_main_class_name(),
     "-version"
   )
   beautier::check_file_exists(cmds[1], "cmds[1]")
@@ -71,7 +71,7 @@ create_beast2_version_cmd_bin <- function(
   beast2_bin_path = get_default_beast2_bin_path()
 ) {
   beautier::check_file_exists(beast2_bin_path, "beast2_bin_path")
-  testit::assert(beastier::is_bin_path(beast2_bin_path))
+  check_true(is_bin_path(beast2_bin_path))
   cmds <- c(
     beast2_bin_path,
     "-version"
