@@ -17,10 +17,10 @@
 #' @author Richèl J.C. Bilderbeek
 #' @export
 get_default_beast2_path <- function(
-  beast2_folder = beastier::get_default_beast2_folder(),
+  beast2_folder = get_default_beast2_folder(),
   os = rappdirs::app_dir()$os
 ) {
-  beastier::get_default_beast2_jar_path(
+  get_default_beast2_jar_path(
     beast2_folder = beast2_folder,
     os = os
   )
