@@ -31,7 +31,7 @@ run_beast2 <- function(
   beast2_path = get_default_beast2_path(),
   verbose = FALSE
 ) {
-  beast2_options <- beastier::create_beast2_options(
+  beast2_options <- create_beast2_options(
     input_filename = input_filename,
     output_state_filename = output_state_filename,
     rng_seed = rng_seed,
@@ -41,5 +41,5 @@ run_beast2 <- function(
     beast2_path = beast2_path,
     verbose = verbose
   )
-  beastier::run_beast2_from_options(beast2_options)
+  run_beast2_from_options(beast2_options)
 }
